@@ -3,30 +3,39 @@
 from aiohttp import web
 import aiohttp_cors
 import asyncio
+from functools import partial
 import os
 import signal
 
 import click
 
-from ..db import init_db, init_db_pool
+from ..db import init_db_pool
+from .alarms import AlarmsView, AlarmView
 from .listeners import ListenersView, ListenerView
-from .proximity import ProximityView
+from .proximity import ProximityView, proximity_task
 from .tags import TagsView, TagView
 from .zones import ZonesView, ZoneView
 from .groups import GroupsView, GroupView
 from ..demo_fe.main import app as demo_fe_app
 
 
+def default_handler(loop, context):
+    print(f"Unhandled exception: {context['message']}", context)
+    loop.stop()
+
+
 @click.command()
 @click.option('--port', '-p', default=5000)
 @click.option('--demo-fe', is_flag=True, default=True)
 def main(port, demo_fe) -> None:
     loop = asyncio.get_event_loop()
+    loop.set_exception_handler(default_handler)
     if signal is not None and os.name != 'nt':
         loop.add_signal_handler(signal.SIGINT, loop.stop)
 
     async def init_db_app(app):
         app['db_pool'] = await init_db_pool()
+        asyncio.ensure_future(proximity_task(app['db_pool']))
 
     app = web.Application()
     app.on_startup.append(init_db_app)
@@ -39,6 +48,8 @@ def main(port, demo_fe) -> None:
     app.router.add_view('/api/proximity', ProximityView)
     app.router.add_view('/api/groups', GroupsView)
     app.router.add_view('/api/groups/{id:\d+}', GroupView, name='group')
+    app.router.add_view('/api/alarms', AlarmsView)
+    app.router.add_view('/api/alarms/{id:\d+}', AlarmView, name='alarm')
 
     cors = aiohttp_cors.setup(app, defaults={
         "*": aiohttp_cors.ResourceOptions(
