@@ -8,4 +8,6 @@ CONFIG = {
     'DB_HOST': os.getenv('DB_HOST', ''),
     'LA_UUID': os.getenv('LA_UUID', UUID(bytes=b'c3wirelesslocanc')),
     'API_RESULT_LIMIT': int(os.getenv('API_RESULT_LIMIT', 100)),
+    'LOCATION_UPDATE_MS': 1000,
+    'MAX_FRAME_SIZE': 1 * 1024 * 1024,  # 1MiB
 }
