@@ -8,13 +8,19 @@ import signal
 import click
 
 from .protocol import ListenerProtocol
-from ..db import init_db, init_db_pool
+from ..db import init_db_pool
+
+
+def default_handler(loop, context):
+    print(f"Unhandled exception: {context['message']}", context)
+    loop.stop()
 
 
 @click.command()
 @click.option('--port', '-p', default=9999)
 def main(port) -> None:
     loop = asyncio.get_event_loop()
+    loop.set_exception_handler(default_handler)
     if signal is not None and os.name != 'nt':
         loop.add_signal_handler(signal.SIGINT, loop.stop)
 
